==> touhoulittlemaid-fabric-1.21.1-0.1.4-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityPicnicMat.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import org.jetbrains.annotations.NotNull;

import javax.annotation.Nullable;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2499;
import net.minecraft.class_2512;
import net.minecraft.class_2520;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;
import net.minecraft.class_9334;
import java.util.UUID;

public class TileEntityPicnicMat extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityPicnicMat> TYPE = class_2591.class_2592.method_20528(TileEntityPicnicMat::new, InitBlocks.PICNIC_MAT).method_11034(null);
    private static final String CENTER_POS_NAME = "CenterPos";
    private static final String STORAGE_ITEM = "StorageItem";
    private static final String SIT_IDS = "SitIds";
    private final ItemStackHandler handler = new ItemStackHandler(9) {
        @Override
        public boolean isItemValid(int slot, @NotNull class_1799 stack) {
            return /*stack.getFoodProperties(null)*/stack.method_57824(class_9334.field_50075) != null;
        }
    };
    private final UUID[] sitIds = new UUID[]{class_156.field_25140, class_156.field_25140, class_156.field_25140, class_156.field_25140};
    private class_2338 centerPos = class_2338.field_10980;

    public TileEntityPicnicMat(class_2338 pos, class_2680 blockState) {
        super(TYPE, pos, blockState);
    }

    public void setCenterPos(class_2338 centerPos) {
        this.centerPos = centerPos;
        this.refresh();
    }

    public void setSitId(int index, UUID uuid) {
        if (index < 0 || index >= 4) {
            return;
        }
        this.sitIds[index] = uuid;
        this.refresh();
    }

    public UUID[] getSitIds() {
        return sitIds;
    }

    public class_2338 getCenterPos() {
        return centerPos;
    }

    public class_1799 getStorageItem(int slotId) {
        return handler.getStackInSlot(slotId);
    }

    public boolean isEmpty(int slotId) {
        return handler.getStackInSlot(slotId).method_7960();
    }

    public void setHandler(ItemStackHandler stackHandler) {
        for (int i = 0; i < stackHandler.getSlots(); i++) {
            class_1799 stack = stackHandler.getStackInSlot(i);
            if (i >= this.handler.getSlots()) {
                return;
            }
            this.handler.setStackInSlot(i, stack);
        }
        this.refresh();
    }

    public ItemStackHandler getHandler() {
        return handler;
    }

    @Override
    protected void method_11007(class_2487 pTag, class_7225.class_7874 pRegistries) {
        getPersistentData().method_10566(CENTER_POS_NAME, class_2512.method_10692(centerPos));
        getPersistentData().method_10566(STORAGE_ITEM, handler.serializeNBT(pRegistries));
        class_2499 listTag = new class_2499();
        for (UUID uuid : sitIds) {
            listTag.add(class_2512.method_25929(uuid));
        }
        getPersistentData().method_10566(SIT_IDS, listTag);
        super.method_11007(pTag, pRegistries);
    }

    @Override
    public void method_11014(class_2487 pTag, class_7225.class_7874 pRegistries) {
        super.method_11014(pTag, pRegistries);
        class_2512.method_10691(getPersistentData(), CENTER_POS_NAME).ifPresent(pos -> centerPos = pos);
        this.handler.deserializeNBT(pRegistries, getPersistentData().method_10562(STORAGE_ITEM));
        class_2499 sitIdsTag = getPersistentData().method_10554(SIT_IDS, class_2520.field_33261);
        int i = 0;
        for (class_2520 tag : sitIdsTag) {
            this.sitIds[i] = class_2512.method_25930(tag);
            i = i + 1;
            if (i >= 4) {
                break;
            }
        }
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    @Override
    public class_2487 method_16887(class_7225.class_7874 pRegistries) {
        return this.method_38244(pRegistries);
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public class_2338 getWorldPosition() {
        return this.field_11867;
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.7.2-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/tileentity/TileEntityPicnicMat.java <==
package com.github.tartaricacid.touhoulittlemaid.tileentity;

import cn.sh1rocu.touhoulittlemaid.api.extension.IBlockEntityPersistentData;
import cn.sh1rocu.touhoulittlemaid.util.itemhandler.ItemStackHandler;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import org.jetbrains.annotations.NotNull;

import javax.annotation.Nullable;
import net.minecraft.class_156;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2499;
import net.minecraft.class_2512;
import net.minecraft.class_2520;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_7225;
import net.minecraft.class_9334;
import java.util.UUID;

public class TileEntityPicnicMat extends class_2586 implements IBlockEntityPersistentData {
    public static final class_2591<TileEntityPicnicMat> TYPE = class_2591.class_2592.method_20528(TileEntityPicnicMat::new, InitBlocks.PICNIC_MAT).method_11034(null);
    private static final String CENTER_POS_NAME = "CenterPos";
    private static final String STORAGE_ITEM = "StorageItem";
    private static final String SIT_IDS = "SitIds";
    private final ItemStackHandler handler = new ItemStackHandler(9) {
        @Override
        public boolean isItemValid(int slot, @NotNull class_1799 stack) {
            return /*stack.getFoodProperties(null)*/stack.method_57824(class_9334.field_50075) != null;
        }
    };
    private final UUID[] sitIds = new UUID[]{class_156.field_25140, class_156.field_25140, class_156.field_25140, class_156.field_25140};
    private class_2338 centerPos = class_2338.field_10980;

    public TileEntityPicnicMat(class_2338 pos, class_2680 blockState) {
        super(TYPE, pos, blockState);
    }

    public void setCenterPos(class_2338 centerPos) {
        this.centerPos = centerPos;
        this.refresh();
    }

    public void setSitId(int index, UUID uuid) {
        if (index < 0 || index >= 4) {
            return;
        }
        this.sitIds[index] = uuid;
        this.refresh();
    }

    public UUID[] getSitIds() {
        return sitIds;
    }

    public class_2338 getCenterPos() {
        return centerPos;
    }

    public class_1799 getStorageItem(int slotId) {
        return handler.getStackInSlot(slotId);
    }

    public boolean isEmpty(int slotId) {
        return handler.getStackInSlot(slotId).method_7960();
    }

    public void setHandler(ItemStackHandler stackHandler) {
        for (int i = 0; i < stackHandler.getSlots(); i++) {
            class_1799 stack = stackHandler.getStackInSlot(i);
            if (i >= this.handler.getSlots()) {
                return;
            }
            this.handler.setStackInSlot(i, stack);
        }
        this.refresh();
    }

    public ItemStackHandler getHandler() {
        return handler;
    }

    @Override
    protected void method_11007(class_2487 pTag, class_7225.class_7874 pRegistries) {
        tlm$getPersistentData().method_10566(CENTER_POS_NAME, class_2512.method_10692(centerPos));
        tlm$getPersistentData().method_10566(STORAGE_ITEM, handler.serializeNBT(pRegistries));
        class_2499 listTag = new class_2499();
        for (UUID uuid : sitIds) {
            listTag.add(class_2512.method_25929(uuid));
        }
        tlm$getPersistentData().method_10566(SIT_IDS, listTag);
        super.method_11007(pTag, pRegistries);
    }

    @Override
    public void method_11014(class_2487 pTag, class_7225.class_7874 pRegistries) {
        super.method_11014(pTag, pRegistries);
        class_2512.method_10691(tlm$getPersistentData(), CENTER_POS_NAME).ifPresent(pos -> centerPos = pos);
        this.handler.deserializeNBT(pRegistries, tlm$getPersistentData().method_10562(STORAGE_ITEM));
        class_2499 sitIdsTag = tlm$getPersistentData().method_10554(SIT_IDS, class_2520.field_33261);
        int i = 0;
        for (class_2520 tag : sitIdsTag) {
            this.sitIds[i] = class_2512.method_25930(tag);
            i = i + 1;
            if (i >= 4) {
                break;
            }
        }
    }

    public void refresh() {
        this.method_5431();
        if (field_11863 != null) {
            class_2680 state = field_11863.method_8320(field_11867);
            field_11863.method_8413(field_11867, state, state, class_2248.field_31036);
        }
    }

    @Override
    public class_2487 method_16887(class_7225.class_7874 pRegistries) {
        return this.method_38244(pRegistries);
    }

    @Nullable
    @Override
    public class_2596<class_2602> method_38235() {
        return class_2622.method_38585(this);
    }

    public class_2338 getWorldPosition() {
        return this.field_11867;
    }
}
